@@ -13,10 +13,10 @@ from vortex.Payload import Payload
 
 from peek_plugin_base.worker import CeleryDbConn
 from peek_plugin_base.worker.CeleryApp import celeryApp
-from peek_plugin_graphdb._private.storage.GraphDbCompilerQueue import \
-    GraphDbCompilerQueue
-from peek_plugin_graphdb._private.storage.GraphDbEncodedChunk import \
-    GraphDbEncodedChunk
+from peek_plugin_graphdb._private.storage.GraphDbCompilerQueue import (
+    GraphDbCompilerQueue,
+)
+from peek_plugin_graphdb._private.storage.GraphDbEncodedChunk import GraphDbEncodedChunk
 from peek_plugin_graphdb._private.storage.GraphDbSegment import GraphDbSegment
 
 logger = logging.getLogger(__name__)
@@ -34,7 +34,7 @@ Compile the graphDb indexes
 @DeferrableTask
 @celeryApp.task(bind=True)
 def compileSegmentChunk(self, payloadEncodedArgs: bytes) -> List[int]:
-    """ Compile GraphDb Index Task
+    """Compile GraphDb Index Task
 
     :param self: The reference to this celery task
     :param payloadEncodedArgs: An encoded payload containing the queue tuples.
@@ -73,9 +73,9 @@ def compileSegmentChunk(self, payloadEncodedArgs: bytes) -> List[int]:
     return list(set([i.chunkKey for i in queueItems]))
 
 
-def _compileSegmentChunk(conn, transaction,
-                         modelSetId: int,
-                         queueItems: List[GraphDbCompilerQueue]) -> None:
+def _compileSegmentChunk(
+    conn, transaction, modelSetId: int, queueItems: List[GraphDbCompilerQueue]
+) -> None:
     chunkKeys = list(set([i.chunkKey for i in queueItems]))
 
     compiledTable = GraphDbEncodedChunk.__table__
@@ -83,8 +83,11 @@ def _compileSegmentChunk(conn, transaction,
 
     startTime = datetime.now(pytz.utc)
 
-    logger.debug("Staring compile of %s queueItems in %s",
-                 len(queueItems), (datetime.now(pytz.utc) - startTime))
+    logger.debug(
+        "Staring compile of %s queueItems in %s",
+        len(queueItems),
+        (datetime.now(pytz.utc) - startTime),
+    )
 
     # Get Model Sets
 
@@ -107,21 +110,22 @@ def _compileSegmentChunk(conn, transaction,
                 continue
 
         chunksToDelete.append(chunkKey)
-        inserts.append(dict(
-            modelSetId=modelSetId,
-            chunkKey=chunkKey,
-            encodedData=graphDbIndexChunkEncodedPayload,
-            encodedHash=encodedHash,
-            lastUpdate=lastUpdate))
+        inserts.append(
+            dict(
+                modelSetId=modelSetId,
+                chunkKey=chunkKey,
+                encodedData=graphDbIndexChunkEncodedPayload,
+                encodedHash=encodedHash,
+                lastUpdate=lastUpdate,
+            )
+        )
 
     # Add any chnuks that we need to delete that we don't have new data for, here
     chunksToDelete.extend(list(existingHashes))
 
     if chunksToDelete:
         # Delete the old chunks
-        conn.execute(
-            compiledTable.delete(compiledTable.c.chunkKey.in_(chunksToDelete))
-        )
+        conn.execute(compiledTable.delete(compiledTable.c.chunkKey.in_(chunksToDelete)))
 
     if inserts:
         newIdGen = CeleryDbConn.prefetchDeclarativeIds(GraphDbSegment, len(inserts))
@@ -134,24 +138,32 @@ def _compileSegmentChunk(conn, transaction,
     if inserts:
         conn.execute(compiledTable.insert(), inserts)
 
-    logger.debug("Compiled %s Segments, %s missing, in %s",
-                 len(inserts),
-                 len(chunkKeys) - len(inserts), (datetime.now(pytz.utc) - startTime))
+    logger.debug(
+        "Compiled %s Segments, %s missing, in %s",
+        len(inserts),
+        len(chunkKeys) - len(inserts),
+        (datetime.now(pytz.utc) - startTime),
+    )
 
     total += len(inserts)
 
     transaction.commit()
-    logger.info("Compiled and Committed %s EncodedSegmentChunks in %s",
-                total, (datetime.now(pytz.utc) - startTime))
+    logger.info(
+        "Compiled and Committed %s EncodedSegmentChunks in %s",
+        total,
+        (datetime.now(pytz.utc) - startTime),
+    )
 
 
 def _loadExistingHashes(conn, chunkKeys: List[str]) -> Dict[str, str]:
     compiledTable = GraphDbEncodedChunk.__table__
 
-    results = conn.execute(select(
-        columns=[compiledTable.c.chunkKey, compiledTable.c.encodedHash],
-        whereclause=compiledTable.c.chunkKey.in_(chunkKeys)
-    )).fetchall()
+    results = conn.execute(
+        select(
+            columns=[compiledTable.c.chunkKey, compiledTable.c.encodedHash],
+            whereclause=compiledTable.c.chunkKey.in_(chunkKeys),
+        )
+    ).fetchall()
 
     return {result[0]: result[1] for result in results}
 
@@ -161,12 +173,13 @@ def _buildIndex(chunkKeys) -> Dict[str, bytes]:
 
     try:
         indexQry = (
-            session.query(GraphDbSegment.chunkKey, GraphDbSegment.key,
-                          GraphDbSegment.segmentJson)
-                .filter(GraphDbSegment.chunkKey.in_(chunkKeys))
-                .order_by(GraphDbSegment.key)
-                .yield_per(1000)
-                .all()
+            session.query(
+                GraphDbSegment.chunkKey, GraphDbSegment.key, GraphDbSegment.segmentJson
+            )
+            .filter(GraphDbSegment.chunkKey.in_(chunkKeys))
+            .order_by(GraphDbSegment.key)
+            .yield_per(1000)
+            .all()
         )
 
         # Create the ChunkKey -> {id -> packedJson, id -> packedJson, ....]
