@@ -12,6 +12,7 @@ import {
     TupleStorageFactoryService,
     VortexService,
     VortexStatusService,
+    TupleStorageBatchSaveArguments,
 } from "@synerty/vortexjs";
 
 import {
@@ -27,7 +28,7 @@ import { PrivateSegmentLoaderStatusTuple } from "./PrivateSegmentLoaderStatusTup
 
 import { GraphDbPackedSegmentTuple } from "./GraphDbPackedSegmentTuple";
 import {
-    DeviceOfflineCacheControllerService,
+    DeviceOfflineCacheService,
     OfflineCacheStatusTuple,
 } from "@peek/peek_core_device";
 
@@ -120,7 +121,12 @@ function keyChunk(modelSetKey: string, key: string): string {
 @Injectable()
 export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
     private UPDATE_CHUNK_FETCH_SIZE = 10;
-    private OFFLINE_CHECK_PERIOD_MS = 15 * 60 * 1000; // 15 minutes
+
+    // Every 100 chunks from the server
+    private SAVE_POINT_ITERATIONS = 100;
+
+    // Saving the cache after each chunk is so expensive, we only do it every 20 or so
+    private chunksSavedSinceLastIndexSave = 0;
 
     private index = new SegmentIndexUpdateDateTuple();
     private askServerChunks: SegmentIndexUpdateDateTuple[] = [];
@@ -138,13 +144,15 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
         private vortexStatusService: VortexStatusService,
         storageFactory: TupleStorageFactoryService,
         private tupleService: GraphDbTupleService,
-        private deviceCacheControllerService: DeviceOfflineCacheControllerService
+        private deviceCacheControllerService: DeviceOfflineCacheService
     ) {
         super();
 
         this.storage = new TupleOfflineStorageService(
             storageFactory,
-            new TupleOfflineStorageNameService(graphDbCacheStorageName)
+            new TupleOfflineStorageNameService(
+                graphDbCacheStorageName + ".segment"
+            )
         );
 
         this.setupVortexSubscriptions();
@@ -175,6 +183,16 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
         return this._status;
     }
 
+    getSegment(
+        modelSetKey: string,
+        segmentKey: string
+    ): Promise<GraphDbLinkedSegment | null> {
+        return this.getSegments(modelSetKey, [segmentKey]) //
+            .then((segmentsByKey: SegmentResultI) => {
+                return segmentsByKey[segmentKey];
+            });
+    }
+
     /** Get Segments
      *
      * Get the objects with matching keywords from the index..
@@ -185,7 +203,7 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
             throw new Error("We've been passed a null/empty keys");
         }
 
-        if (!this.deviceCacheControllerService.cachingEnabled) {
+        if (this.vortexStatusService.snapshot.isOnline) {
             let ts = new TupleSelector(GraphDbPackedSegmentTuple.tupleName, {
                 modelSetKey: modelSetKey,
                 keys: keys,
@@ -222,6 +240,15 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
                 );
         }
 
+        if (!this.deviceCacheControllerService.offlineModeEnabled) {
+            throw new Error(
+                "Peek is not online," +
+                    " and offline caching is not enabled" +
+                    " or has not completed loading." +
+                    " The ItemKeyIndex won't work."
+            );
+        }
+
         if (this.isReady())
             return this.getSegmentsWhenReady(modelSetKey, keys).then(
                 (segments) => this._makeDictFromSegments(segments)
@@ -297,7 +324,7 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
             )
             .pipe(takeUntil(this.onDestroyEvent))
             .subscribe((payloadEnvelope: PayloadEnvelope) => {
-                this.processSegmentsFromServer(payloadEnvelope);
+                this.processChunksFromServer(payloadEnvelope);
             });
 
         // If the vortex service comes back online, update the watch grids.
@@ -309,7 +336,7 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
 
     private areWeTalkingToTheServer(): boolean {
         return (
-            this.deviceCacheControllerService.cachingEnabled &&
+            this.deviceCacheControllerService.offlineModeEnabled &&
             this.vortexStatusService.snapshot.isOnline
         );
     }
@@ -393,94 +420,100 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
 
         if (this.askServerChunks.length == 0) return;
 
-        let indexChunk: SegmentIndexUpdateDateTuple =
-            this.askServerChunks.pop();
-        let filt = extend({}, clientSegmentWatchUpdateFromDeviceFilt);
-        filt[cacheAll] = true;
-        let pl = new Payload(filt, [indexChunk]);
-        this.vortexService.sendPayload(pl);
+        this.deviceCacheControllerService //
+            .waitForGarbageCollector()
+            .then(() => {
+                let indexChunk: SegmentIndexUpdateDateTuple =
+                    this.askServerChunks.pop();
+                let filt = extend({}, clientSegmentWatchUpdateFromDeviceFilt);
+                filt[cacheAll] = true;
+                let pl = new Payload(filt, [indexChunk]);
+                this.vortexService.sendPayload(pl);
 
-        this._status.lastCheck = new Date();
-        this._notifyStatus();
+                this._status.lastCheck = new Date();
+                this._notifyStatus();
+            });
     }
 
     /** Process Segmentes From Server
      *
      * Process the grids the server has sent us.
      */
-    private processSegmentsFromServer(payloadEnvelope: PayloadEnvelope) {
+    private async processChunksFromServer(
+        payloadEnvelope: PayloadEnvelope
+    ): Promise<void> {
         if (payloadEnvelope.result != null && payloadEnvelope.result != true) {
             console.log(`ERROR: ${payloadEnvelope.result}`);
             return;
         }
 
-        payloadEnvelope
-            .decodePayload()
-            .then((payload: Payload) => this.storeSegmentPayload(payload))
-            .then(() => {
-                if (this.askServerChunks.length == 0) {
-                    this.index.initialLoadComplete = true;
-                    this._hasLoaded = true;
-                    this._hasLoadedSubject.next();
-                } else if (payloadEnvelope.filt[cacheAll] == true) {
-                    this.askServerForNextUpdateChunk();
-                }
-            })
-            .then(() => this._notifyStatus())
-            .catch(
-                (e) => `SegmentCache.processSegmentsFromServer failed: ${e}`
-            );
-    }
-
-    private storeSegmentPayload(payload: Payload) {
-        let tuplesToSave: EncodedSegmentChunkTuple[] = <
+        const tuplesToSave: EncodedSegmentChunkTuple[] = <
             EncodedSegmentChunkTuple[]
-        >payload.tuples;
-        if (tuplesToSave.length == 0) return;
+        >payloadEnvelope.data;
 
-        // 2) Store the index
-        this.storeSegmentChunkTuples(tuplesToSave)
-            .then(() => {
-                // 3) Store the update date
+        try {
+            await this.storeChunkTuples(tuplesToSave);
+        } catch (e) {
+            console.log(`PrivateSegmentLoaderService.storeChunkTuples: ${e}`);
+        }
 
-                for (let graphDbIndex of tuplesToSave) {
-                    this.index.updateDateByChunkKey[graphDbIndex.chunkKey] =
-                        graphDbIndex.lastUpdate;
-                }
+        if (this.askServerChunks.length == 0) {
+            this.index.initialLoadComplete = true;
+            await this.saveChunkCacheIndex(true);
+            this._hasLoaded = true;
+            this._hasLoadedSubject.next();
+        } else if (payloadEnvelope.filt[cacheAll] == true) {
+            this.askServerForNextUpdateChunk();
+        }
 
-                return this.storage.saveTuples(new UpdateDateTupleSelector(), [
-                    this.index,
-                ]);
-            })
-            .catch((e) =>
-                console.log(`SegmentCache.storeSegmentPayload: ${e}`)
-            );
+        this._notifyStatus();
     }
 
     /** Store Index Bucket
      * Stores the index bucket in the local db.
      */
-    private storeSegmentChunkTuples(
-        encodedSegmentChunkTuples: EncodedSegmentChunkTuple[]
+    private async storeChunkTuples(
+        tuplesToSave: EncodedSegmentChunkTuple[]
     ): Promise<void> {
-        let retPromise: any;
-        retPromise = this.storage.transaction(true).then((tx) => {
-            let promises = [];
+        // noinspection BadExpressionStatementJS
+        const Selector = SegmentChunkTupleSelector;
 
-            for (let encodedSegmentChunkTuple of encodedSegmentChunkTuples) {
-                promises.push(
-                    tx.saveTuplesEncoded(
-                        new SegmentChunkTupleSelector(
-                            encodedSegmentChunkTuple.chunkKey
-                        ),
-                        encodedSegmentChunkTuple.encodedData
-                    )
-                );
-            }
+        if (tuplesToSave.length == 0) return;
 
-            return Promise.all(promises).then(() => tx.close());
-        });
-        return retPromise;
+        const batchStore: TupleStorageBatchSaveArguments[] = [];
+        for (const tuple of tuplesToSave) {
+            batchStore.push({
+                tupleSelector: new Selector(tuple.chunkKey),
+                vortexMsg: tuple.encodedData,
+            });
+        }
+
+        await this.storage.batchSaveTuplesEncoded(batchStore);
+
+        for (const tuple of tuplesToSave) {
+            this.index.updateDateByChunkKey[tuple.chunkKey] = tuple.lastUpdate;
+        }
+        await this.saveChunkCacheIndex(true);
+    }
+
+    /** Store Chunk Cache Index
+     *
+     * Updates our running tab of the update dates of the cached chunks
+     *
+     */
+    private async saveChunkCacheIndex(force = false): Promise<void> {
+        if (
+            this.chunksSavedSinceLastIndexSave <= this.SAVE_POINT_ITERATIONS &&
+            !force
+        ) {
+            return;
+        }
+
+        this.chunksSavedSinceLastIndexSave = 0;
+
+        await this.storage.saveTuples(new UpdateDateTupleSelector(), [
+            this.index,
+        ]);
     }
 
     /** Get Segments When Ready
@@ -528,7 +561,7 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
      * Get the objects with matching keywords from the index..
      *
      */
-    private getSegmentsForKeys(
+    private async getSegmentsForKeys(
         modelSetKey: string,
         keys: string[],
         chunkKey: string
@@ -538,44 +571,36 @@ export class PrivateSegmentLoaderService extends NgLifeCycleEvents {
             return Promise.resolve([]);
         }
 
-        let retPromise: any;
-        retPromise = this.storage
-            .loadTuplesEncoded(new SegmentChunkTupleSelector(chunkKey))
-            .then((vortexMsg: string) => {
-                if (vortexMsg == null) {
-                    return [];
-                }
+        const vortexMsg: string = await this.storage.loadTuplesEncoded(
+            new SegmentChunkTupleSelector(chunkKey)
+        );
+        if (vortexMsg == null) {
+            return [];
+        }
 
-                return Payload.fromEncodedPayload(vortexMsg)
-                    .then((payload: Payload) => JSON.parse(<any>payload.tuples))
-                    .then((chunkData: { [key: number]: string }) => {
-                        let foundSegments: GraphDbLinkedSegment[] = [];
+        const payload: Payload = await Payload.fromEncodedPayload(vortexMsg);
+        const chunkData: { [key: number]: string } = JSON.parse(
+            <any>payload.tuples[0]
+        );
+        let foundSegments: GraphDbLinkedSegment[] = [];
 
-                        for (let key of keys) {
-                            // Find the keyword, we're just iterating
-                            if (!chunkData.hasOwnProperty(key)) {
-                                console.log(
-                                    `WARNING: Segment ${key} is missing from index,` +
-                                        ` chunkKey ${chunkKey}`
-                                );
-                                continue;
-                            }
+        for (let key of keys) {
+            // Find the keyword, we're just iterating
+            if (!chunkData.hasOwnProperty(key)) {
+                console.log(
+                    `WARNING: Segment ${key} is missing from index,` +
+                        ` chunkKey ${chunkKey}`
+                );
+                continue;
+            }
 
-                            // Create the new object
-                            let newObject = new GraphDbLinkedSegment();
-                            newObject.unpackJson(
-                                chunkData[key],
-                                key,
-                                modelSetKey
-                            );
-                            foundSegments.push(newObject);
-                        }
+            // Create the new object
+            let newObject = new GraphDbLinkedSegment();
+            newObject.unpackJson(chunkData[key], key, modelSetKey);
+            foundSegments.push(newObject);
+        }
 
-                        return foundSegments;
-                    });
-            });
-
-        return retPromise;
+        return foundSegments;
     }
 
     private _makeDictFromSegments(
