@@ -6,12 +6,13 @@ from vortex.Tuple import Tuple, addTupleType
 
 @addTupleType
 class GraphDbImportVertexTuple(Tuple):
-    """ Graph DB Vertex Tuple
+    """Graph DB Vertex Tuple
 
     This tuple represents a vertex in the GraphDb plugin.
 
     """
-    __tupleType__ = graphDbTuplePrefix + 'GraphDbImportVertexTuple'
+
+    __tupleType__ = graphDbTuplePrefix + "GraphDbImportVertexTuple"
     __slots__ = ("k", "p")
     __rawJonableFields__ = ["p"]
 
@@ -34,10 +35,7 @@ class GraphDbImportVertexTuple(Tuple):
         self.p = val
 
     def __repr__(self):
-        return '%s.%s' % (self.k, self.p)
+        return "%s.%s" % (self.k, self.p)
 
     def packJsonDict(self) -> Dict[str, Any]:
-        return dict(
-            k=self.k,
-            p=self.p
-        )
+        return dict(k=self.k, p=self.p)
